### Customize Your Wordlist Editor Sessions

You can customize the appearance of the Wordlist Editor by generating specific URLs that store your desired layout. By bookmarking the generated URL, you can open the Wordlist Editor in your desired flavor. All you need to do is to check your desired parameters in the checkbox below.

Basic Parameters

Show on Start
Menu Filters Database
Basic Fields
Cognate ID
Preview

Transformations

SAMPA
Highlight

Other Settings

Remote file